summaryrefslogtreecommitdiff
path: root/perl.c
diff options
context:
space:
mode:
authorNicholas Clark <nick@ccl4.org>2003-11-03 06:46:48 +0000
committerNicholas Clark <nick@ccl4.org>2003-11-03 06:46:48 +0000
commit008fb0c0b128e68050936412d62bf4def14fc864 (patch)
tree49c839707619bafbf10c3976a3e2f485c1e2f8af /perl.c
parent8e90d776335dcf68d19230bed1f95b7f5237577b (diff)
downloadperl-008fb0c0b128e68050936412d62bf4def14fc864.tar.gz
s/new_hash/rehash/g (Stas suggested a better name)
p4raw-id: //depot/perl@21638
Diffstat (limited to 'perl.c')
-rw-r--r--perl.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/perl.c b/perl.c
index 3860d2dfef..4157df9ec4 100644
--- a/perl.c
+++ b/perl.c
@@ -942,11 +942,11 @@ setuid perl scripts securely.\n");
#if defined(USE_HASH_SEED) || defined(USE_HASH_SEED_EXPLICIT)
/* [perl #22371] Algorimic Complexity Attack on Perl 5.6.1, 5.8.0
* This MUST be done before any hash stores or fetches take place.
* If you set PL_hash_seed (and assumedly also PL_hash_seed_set) yourself,
* it is your responsibility to provide a good random seed!
* You can also define PERL_HASH_SEED in compile time, see hv.h. */
- if (!PL_new_hash_seed_set)
- PL_new_hash_seed = get_hash_seed();
+ if (!PL_rehash_seed_set)
+ PL_rehash_seed = get_hash_seed();
{
char *s = PerlEnv_getenv("PERL_HASH_SEED_DEBUG");
@@ -955,7 +955,7 @@ setuid perl scripts securely.\n");
if (i == 1)
PerlIO_printf(Perl_debug_log, "HASH_SEED = %"UVuf"\n",
- PL_new_hash_seed);
+ PL_rehash_seed);
}
}
#endif /* #if defined(USE_HASH_SEED) || defined(USE_HASH_SEED_EXPLICIT) */
@@ -942,11 +942,11 @@ setuid perl scripts securely.\n");
/* [perl #22371] Algorimic Complexity Attack on Perl 5.6.1, 5.8.0
* This MUST be done before any hash stores or fetches take place.
- * If you set PL_hash_seed (and assumedly also PL_hash_seed_set) yourself,
- * it is your responsibility to provide a good random seed!
+ * If you set PL_rehash_seed (and assumedly also PL_rehash_seed_set)
+ * yourself, it is your responsibility to provide a good random seed!
* You can also define PERL_HASH_SEED in compile time, see hv.h. */